==> moonlight-1.20-2.16.14-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/resources/ResType.java <==
package net.mehvahdjukaar.moonlight.api.resources;


import net.minecraft.class_2960;
import net.minecraft.class_6862;

public enum ResType {
    GENERIC("%s"),
    TAGS("tags/%s.json"),
    LOOT_TABLES("loot_tables/%s.json"),
    BLOCK_LOOT_TABLES("loot_tables/blocks/%s.json"),
    RECIPES("recipes/%s.json"),
    ADVANCEMENTS("advancements/%s.json"),
    CONFIGURED_FEATURES("worldgen/configured_feature/%s.json"),
    STRUCTURE("worldgen/structure/%s.json"),
    STRUCTURE_SET("worldgen/structure_set/%s.json"),
    TEMPLATE_POOL("worldgen/template_pool/%s.json"),

    LANG("lang/%s.json"),
    TEXTURES("textures/%s.png"),
    BLOCK_TEXTURES("textures/block/%s.png"),
    ITEM_TEXTURES("textures/item/%s.png"),
    ENTITY_TEXTURES("textures/entity/%s.png"),
    PARTICLE_TEXTURES("textures/particle/%s.png"),
    MCMETA("textures/%s.png.mcmeta"),
    BLOCK_MCMETA("textures/block/%s.png.mcmeta"),
    ITEM_MCMETA("textures/item/%s.png.mcmeta"),
    MODELS("models/%s.json"),
    BLOCK_MODELS("models/block/%s.json"),
    ITEM_MODELS("models/item/%s.json"),
    BLOCKSTATES("blockstates/%s.json"),
    PARTICLES("particles/%s.json"),
    MOB_EFFECT_TEXTURES("mob_effect/%s.json"),
    JSON("%s.json"),
    PNG("%s.png");

    private final String loc;

    ResType(String loc) {
        this.loc = loc;
    }


    public class_2960 getPath(class_2960 relativeLocation) {
        return new class_2960(relativeLocation.method_12836(), String.format(this.loc, relativeLocation.method_12832()));
    }

    public class_2960 getPath(String relativeLocation) {
        return this.getPath(new class_2960(relativeLocation));
    }

    public static class_2960 getTagPath(class_6862<?> tag) {
     return    TAGS.getPath(tag.comp_327().method_45138(tag.comp_326().method_29177().method_12832() + "s/"));
    }

}

==> moonlight-1.21-2.25.0-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/resources/ResType.java <==
package net.mehvahdjukaar.moonlight.api.resources;


import net.minecraft.class_2960;
import net.minecraft.class_6862;

public enum ResType {
    GENERIC("%s"),
    TAGS("tags/%s.json"),
    LOOT_TABLES("loot_table/%s.json"),
    BLOCK_LOOT_TABLES("loot_table/blocks/%s.json"),
    RECIPES("recipe/%s.json"),
    ADVANCEMENTS("advancement/%s.json"),
    CONFIGURED_FEATURES("worldgen/configured_feature/%s.json"),
    STRUCTURE("worldgen/structure/%s.json"),
    STRUCTURE_SET("worldgen/structure_set/%s.json"),
    TEMPLATE_POOL("worldgen/template_pool/%s.json"),

    LANG("lang/%s.json"),
    TEXTURES("textures/%s.png"),
    BLOCK_TEXTURES("textures/block/%s.png"),
    ITEM_TEXTURES("textures/item/%s.png"),
    ENTITY_TEXTURES("textures/entity/%s.png"),
    PARTICLE_TEXTURES("textures/particle/%s.png"),
    MCMETA("textures/%s.png.mcmeta"),
    BLOCK_MCMETA("textures/block/%s.png.mcmeta"),
    ITEM_MCMETA("textures/item/%s.png.mcmeta"),
    MODELS("models/%s.json"),
    BLOCK_MODELS("models/block/%s.json"),
    ITEM_MODELS("models/item/%s.json"),
    BLOCKSTATES("blockstates/%s.json"),
    PARTICLES("particles/%s.json"),
    MOB_EFFECT_TEXTURES("mob_effect/%s.json"),
    JSON("%s.json"),
    PNG("%s.png");

    private final String loc;

    ResType(String loc) {
        this.loc = loc;
    }


    public class_2960 getPath(class_2960 relativeLocation) {
        return relativeLocation.method_45136(String.format(this.loc, relativeLocation.method_12832()));
    }

    public class_2960 getPath(String relativeLocation) {
        return this.getPath(class_2960.method_60654(relativeLocation));
    }

    public static class_2960 getTagPath(class_6862<?> tag) {
        return TAGS.getPath(tag.comp_327().method_45138(tag.comp_326().method_29177().method_12832() + "/"));
    }

}
